@@ -7,10 +7,11 @@
 DOCUMENTATION = r"""
 ---
 module: event_syslog_config_info
-short_description: Information module for Event Syslog Config
+short_description: Information module for Event Syslog
+  Config
 description:
-- Get all Event Syslog Config.
-- Get Syslog Destination.
+  - Get all Event Syslog Config.
+  - Get Syslog Destination.
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -21,49 +22,56 @@ options:
     type: dict
   configId:
     description:
-    - ConfigId query parameter. Config id of syslog server.
+      - ConfigId query parameter. Config id of syslog
+        server.
     type: str
   name:
     description:
-    - Name query parameter. Name of syslog server.
+      - Name query parameter. Name of syslog server.
     type: str
   protocol:
     description:
-    - Protocol query parameter. Protocol of syslog server.
+      - Protocol query parameter. Protocol of syslog
+        server.
     type: str
   offset:
     description:
-    - Offset query parameter. The number of syslog configuration's to offset in the resultset whose default value 0.
+      - Offset query parameter. The number of syslog
+        configuration's to offset in the resultset whose
+        default value 0.
     type: float
   limit:
     description:
-    - Limit query parameter. The number of syslog configuration's to limit in the resultset whose default value 10.
+      - Limit query parameter. The number of syslog
+        configuration's to limit in the resultset whose
+        default value 10.
     type: float
   sortBy:
     description:
-    - SortBy query parameter. SortBy field name.
+      - SortBy query parameter. SortBy field name.
     type: str
   order:
     description:
-    - Order query parameter.
+      - Order query parameter.
     type: str
 requirements:
-- dnacentersdk >= 2.7.1
-- python >= 3.5
+  - dnacentersdk >= 2.10.1
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for Event Management GetSyslogDestination
-  description: Complete reference of the GetSyslogDestination API.
-  link: https://developer.cisco.com/docs/dna-center/#!get-syslog-destination
+  - name: Cisco DNA Center documentation for Event Management
+      GetSyslogDestination
+    description: Complete reference of the GetSyslogDestination
+      API.
+    link: https://developer.cisco.com/docs/dna-center/#!get-syslog-destination
 notes:
   - SDK Method used are
     event_management.EventManagement.get_syslog_destination,
-
   - Paths used are
     get /dna/intent/api/v1/event/syslog-config,
-
 """
 
 EXAMPLES = r"""
+---
 - name: Get all Event Syslog Config
   cisco.dnac.event_syslog_config_info:
     dnac_host: "{{dnac_host}}"
@@ -82,7 +90,6 @@ EXAMPLES = r"""
     sortBy: string
     order: string
   register: result
-
 """
 RETURN = r"""
 dnac_response:
