@@ -9,8 +9,8 @@ DOCUMENTATION = r"""
 module: file_info
 short_description: Information module for File
 description:
-- Get File by id.
-- Downloads a file specified by fileId.
+  - Get File by id.
+  - Downloads a file specified by fileId.
 version_added: '3.1.0'
 extends_documentation_fragment:
   - cisco.dnac.module_info
@@ -21,37 +21,39 @@ options:
     type: dict
   fileId:
     description:
-    - FileId path parameter. File Identification number.
+      - FileId path parameter. File Identification number.
     type: str
   dirPath:
     description:
-    - Directory absolute path. Defaults to the current working directory.
+      - Directory absolute path. Defaults to the current
+        working directory.
     type: str
   saveFile:
     description:
-    - Enable or disable automatic file creation of raw response.
+      - Enable or disable automatic file creation of
+        raw response.
     type: bool
   filename:
     description:
-    - The filename used to save the download file.
+      - The filename used to save the download file.
     type: str
 requirements:
-- dnacentersdk >= 2.7.1
-- python >= 3.5
+  - dnacentersdk >= 2.10.1
+  - python >= 3.5
 seealso:
-- name: Cisco DNA Center documentation for File DownloadAFileByFileId
-  description: Complete reference of the DownloadAFileByFileId API.
-  link: https://developer.cisco.com/docs/dna-center/#!download-a-file-by-file-id
+  - name: Cisco DNA Center documentation for File DownloadAFileByFileId
+    description: Complete reference of the DownloadAFileByFileId
+      API.
+    link: https://developer.cisco.com/docs/dna-center/#!download-a-file-by-file-id
 notes:
   - SDK Method used are
     file.File.download_a_file_by_fileid,
-
   - Paths used are
     get /dna/intent/api/v1/file/{fileId},
-
 """
 
 EXAMPLES = r"""
+---
 - name: Get File by id
   cisco.dnac.file_info:
     dnac_host: "{{dnac_host}}"
@@ -64,7 +66,6 @@ EXAMPLES = r"""
     headers: "{{my_headers | from_json}}"
     fileId: string
   register: result
-
 """
 RETURN = r"""
 dnac_response:
