@@ -10,6 +10,7 @@ The module file for nxos_ntp_global
 
 from __future__ import absolute_import, division, print_function
 
+
 __metaclass__ = type
 
 DOCUMENTATION = """
@@ -19,8 +20,9 @@ description:
 - This module manages ntp configuration on devices running Cisco NX-OS.
 version_added: 2.6.0
 notes:
-- Tested against NX-OS 9.3.6.
+- Tested against NX-OS 9.3.6 on Cisco Nexus Switches.
 - This module works with connection C(network_cli) and C(httpapi).
+- Tested against Cisco MDS NX-OS 9.2(2) with connection C(network_cli).
 author: Nilashish Chakraborty (@NilashishC)
 options:
   running_config:
@@ -37,7 +39,9 @@ options:
     type: dict
     suboptions:
       access_group:
-        description: NTP access-group.
+        description:
+          - NTP access-group.
+          - This option is unsupported on MDS switches.
         type: dict
         suboptions:
           match_all:
@@ -114,13 +118,16 @@ options:
       master:
         description:
           - Act as NTP master clock.
+          - This option is unsupported on MDS switches.
         type: dict
         suboptions:
           stratum:
             description: Stratum number.
             type: int
       passive:
-        description: NTP passive command.
+        description:
+          - NTP passive command.
+          - This option is unsupported on MDS switches.
         type: bool
       peers:
         description: NTP Peers.
@@ -147,9 +154,12 @@ options:
             description:
               - Preferred Server.
             type: bool
-          use_vrf:
-            description: Display per-VRF information.
+          vrf:
+            description:
+              - Display per-VRF information.
+              - This option is unsupported on MDS switches.
             type: str
+            aliases: ["use_vrf"]
       servers:
         description: NTP servers.
         type: list
@@ -175,11 +185,16 @@ options:
             description:
               - Preferred Server.
             type: bool
-          use_vrf:
-            description: Display per-VRF information.
+          vrf:
+            description:
+              - Display per-VRF information.
+              - This option is not applicable for MDS switches.
             type: str
+            aliases: ["use_vrf"]
       source:
-        description: Source of NTP packets.
+        description:
+          - Source of NTP packets.
+          - This option is unsupported on MDS switches.
         type: str
       source_interface:
         description: Source interface sending NTP packets.
@@ -226,7 +241,7 @@ EXAMPLES = """
           - access_list: PeerAcl1
         serve:
           - access_list: ServeAcl1
-      authenticate: True
+      authenticate: true
       authentication_keys:
         - id: 1001
           key: vagwwtKfkv
@@ -234,7 +249,7 @@ EXAMPLES = """
         - id: 1002
           key: vagwwtKfkvgthz
           encryption: 7
-      logging: True
+      logging: true
       master:
         stratum: 2
       peers:
@@ -242,18 +257,18 @@ EXAMPLES = """
           key_id: 1
           maxpoll: 15
           minpoll: 5
-          use_vrf: default
+          vrf: default
         - peer: 192.0.2.2
           key_id: 2
-          prefer: True
-          use_vrf: siteA
+          prefer: true
+          vrf: siteA
       servers:
         - server: 198.51.100.1
           key_id: 2
-          use_vrf: default
+          vrf: default
         - server: 203.0.113.1
           key_id: 1
-          use_vrf: siteB
+          vrf: siteB
 
 # Task output
 # -------------
@@ -278,7 +293,7 @@ EXAMPLES = """
 #        - access_list: PeerAcl1
 #      serve:
 #       - access_list: ServeAcl1
-#    authenticate: True
+#    authenticate: true
 #    authentication_keys:
 #      - id: 1001
 #        key: vagwwtKfkv
@@ -286,7 +301,7 @@ EXAMPLES = """
 #      - id: 1002
 #        key: vagwwtKfkvgthz
 #        encryption: 7
-#    logging: True
+#    logging: true
 #    master:
 #     stratum: 2
 #    peers:
@@ -294,18 +309,18 @@ EXAMPLES = """
 #        key_id: 1
 #        maxpoll: 15
 #        minpoll: 5
-#        use_vrf: default
+#        vrf: default
 #      - peer: 192.0.2.2
 #        key_id: 2
-#        prefer: True
-#        use_vrf: siteA
+#        prefer: true
+#        vrf: siteA
 #    servers:
 #      - server: 198.51.100.1
 #        key_id: 2
-#        use_vrf: default
+#        vrf: default
 #      - server: 203.0.113.1
 #        key_id: 1
-#        use_vrf: siteB
+#        vrf: siteB
 
 # After state:
 # ------------
@@ -347,7 +362,7 @@ EXAMPLES = """
           - access_list: PeerAcl2
         serve:
           - access_list: ServeAcl2
-      logging: True
+      logging: true
       master:
         stratum: 2
       peers:
@@ -355,15 +370,15 @@ EXAMPLES = """
           key_id: 1
           maxpoll: 15
           minpoll: 5
-          use_vrf: default
+          vrf: default
         - peer: 192.0.2.5
           key_id: 2
-          prefer: True
-          use_vrf: siteA
+          prefer: true
+          vrf: siteA
       servers:
         - server: 198.51.100.1
           key_id: 2
-          use_vrf: default
+          vrf: default
     state: replaced
 
 # Task output
@@ -374,7 +389,7 @@ EXAMPLES = """
 #        - access_list: PeerAcl1
 #      serve:
 #       - access_list: ServeAcl1
-#    authenticate: True
+#    authenticate: true
 #    authentication_keys:
 #      - id: 1001
 #        key: vagwwtKfkv
@@ -382,7 +397,7 @@ EXAMPLES = """
 #      - id: 1002
 #        key: vagwwtKfkvgthz
 #        encryption: 7
-#    logging: True
+#    logging: true
 #    master:
 #     stratum: 2
 #    peers:
@@ -390,18 +405,18 @@ EXAMPLES = """
 #        key_id: 1
 #        maxpoll: 15
 #        minpoll: 5
-#        use_vrf: default
+#        vrf: default
 #      - peer: 192.0.2.2
 #        key_id: 2
-#        prefer: True
-#        use_vrf: siteA
+#        prefer: true
+#        vrf: siteA
 #    servers:
 #      - server: 198.51.100.1
 #        key_id: 2
-#        use_vrf: default
+#        vrf: default
 #      - server: 203.0.113.1
 #        key_id: 1
-#        use_vrf: siteB
+#        vrf: siteB
 #
 #  commands:
 #    - "no ntp authenticate"
@@ -421,7 +436,7 @@ EXAMPLES = """
 #        - access_list: PeerAcl2
 #      serve:
 #        - access_list: ServeAcl2
-#    logging: True
+#    logging: true
 #    master:
 #      stratum: 2
 #    peers:
@@ -429,15 +444,15 @@ EXAMPLES = """
 #        key_id: 1
 #        maxpoll: 15
 #        minpoll: 5
-#        use_vrf: default
+#        vrf: default
 #      - peer: 192.0.2.5
 #        key_id: 2
-#        prefer: True
-#        use_vrf: siteA
+#        prefer: true
+#        vrf: siteA
 #    servers:
 #      - server: 198.51.100.1
 #        key_id: 2
-#        use_vrf: default
+#        vrf: default
 
 # After state:
 # ------------
@@ -468,7 +483,7 @@ EXAMPLES = """
 #        - access_list: PeerAcl1
 #      serve:
 #       - access_list: ServeAcl1
-#    authenticate: True
+#    authenticate: true
 #    authentication_keys:
 #      - id: 1001
 #        key: vagwwtKfkv
@@ -476,7 +491,7 @@ EXAMPLES = """
 #      - id: 1002
 #        key: vagwwtKfkvgthz
 #        encryption: 7
-#    logging: True
+#    logging: true
 #    master:
 #     stratum: 2
 #    peers:
@@ -484,18 +499,18 @@ EXAMPLES = """
 #        key_id: 1
 #        maxpoll: 15
 #        minpoll: 5
-#        use_vrf: default
+#        vrf: default
 #      - peer: 192.0.2.2
 #        key_id: 2
-#        prefer: True
-#        use_vrf: siteA
+#        prefer: true
+#        vrf: siteA
 #    servers:
 #      - server: 198.51.100.1
 #        key_id: 2
-#        use_vrf: default
+#        vrf: default
 #      - server: 203.0.113.1
 #        key_id: 1
-#        use_vrf: siteB
+#        vrf: siteB
 #
 #  commands:
 #    - "no ntp authenticate"
@@ -527,7 +542,7 @@ EXAMPLES = """
           - access_list: PeerAcl1
         serve:
           - access_list: ServeAcl1
-      authenticate: True
+      authenticate: true
       authentication_keys:
         - id: 1001
           key: vagwwtKfkv
@@ -535,7 +550,7 @@ EXAMPLES = """
         - id: 1002
           key: vagwwtKfkvgthz
           encryption: 7
-      logging: True
+      logging: true
       master:
         stratum: 2
       peers:
@@ -543,18 +558,18 @@ EXAMPLES = """
           key_id: 1
           maxpoll: 15
           minpoll: 5
-          use_vrf: default
+          vrf: default
         - peer: 192.0.2.2
           key_id: 2
-          prefer: True
-          use_vrf: siteA
+          prefer: true
+          vrf: siteA
       servers:
         - server: 198.51.100.1
           key_id: 2
-          use_vrf: default
+          vrf: default
         - server: 203.0.113.1
           key_id: 1
-          use_vrf: siteB
+          vrf: siteB
     state: rendered
 
 # Task Output (redacted)
@@ -601,7 +616,7 @@ EXAMPLES = """
 #        - access_list: PeerAcl1
 #      serve:
 #       - access_list: ServeAcl1
-#    authenticate: True
+#    authenticate: true
 #    authentication_keys:
 #      - id: 1001
 #        key: vagwwtKfkv
@@ -609,7 +624,7 @@ EXAMPLES = """
 #      - id: 1002
 #        key: vagwwtKfkvgthz
 #        encryption: 7
-#    logging: True
+#    logging: true
 #    master:
 #     stratum: 2
 #    peers:
@@ -617,18 +632,18 @@ EXAMPLES = """
 #        key_id: 1
 #        maxpoll: 15
 #        minpoll: 5
-#        use_vrf: default
+#        vrf: default
 #      - peer: 192.0.2.2
 #        key_id: 2
-#        prefer: True
-#        use_vrf: siteA
+#        prefer: true
+#        vrf: siteA
 #    servers:
 #      - server: 198.51.100.1
 #        key_id: 2
-#        use_vrf: default
+#        vrf: default
 #      - server: 203.0.113.1
 #        key_id: 1
-#        use_vrf: siteB
+#        vrf: siteB
 """
 
 RETURN = """
@@ -685,6 +700,7 @@ parsed:
 """
 
 from ansible.module_utils.basic import AnsibleModule
+
 from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.argspec.ntp_global.ntp_global import (
     Ntp_globalArgs,
 )
