@@ -19,28 +19,24 @@
 
 from __future__ import absolute_import, division, print_function
 
+
 __metaclass__ = type
 
 from textwrap import dedent
-from ansible_collections.cisco.nxos.tests.unit.compat.mock import patch
-from ansible_collections.cisco.nxos.tests.unit.modules.utils import (
-    AnsibleFailJson,
-)
-from ansible_collections.cisco.nxos.plugins.modules import nxos_telemetry
-from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.nxos import (
-    NxosCmdRef,
-)
-from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.config.telemetry.telemetry import (
-    Telemetry,
-)
-from .nxos_module import TestNxosModule, load_fixture, set_module_args
+from unittest.mock import patch
 
 # TBD: These imports / import checks are only needed as a workaround for
 # shippable, which fails this test due to import yaml & import ordereddict.
 import pytest
+
 from ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.nxos import (
     nxosCmdRef_import_check,
 )
+from ansible_collections.cisco.nxos.plugins.modules import nxos_telemetry
+from ansible_collections.cisco.nxos.tests.unit.modules.utils import AnsibleFailJson
+
+from .nxos_module import TestNxosModule, load_fixture, set_module_args
+
 
 msg = nxosCmdRef_import_check()
 ignore_provider_arg = True
@@ -48,43 +44,38 @@ ignore_provider_arg = True
 
 @pytest.mark.skipif(len(msg), reason=msg)
 class TestNxosTelemetryModule(TestNxosModule):
-
     module = nxos_telemetry
 
     def setUp(self):
         super(TestNxosTelemetryModule, self).setUp()
 
         self.mock_FACT_LEGACY_SUBSETS = patch(
-            "ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.facts.facts.FACT_LEGACY_SUBSETS"
+            "ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.facts.facts.FACT_LEGACY_SUBSETS",
         )
         self.FACT_LEGACY_SUBSETS = self.mock_FACT_LEGACY_SUBSETS.start()
 
         self.mock_get_resource_connection_config = patch(
-            "ansible_collections.ansible.netcommon.plugins.module_utils.network.common.cfg.base.get_resource_connection"
-        )
-        self.get_resource_connection_config = (
-            self.mock_get_resource_connection_config.start()
+            "ansible_collections.ansible.netcommon.plugins.module_utils.network.common.cfg.base.get_resource_connection",
         )
+        self.get_resource_connection_config = self.mock_get_resource_connection_config.start()
 
         self.mock_get_resource_connection_facts = patch(
-            "ansible_collections.ansible.netcommon.plugins.module_utils.network.common.facts.facts.get_resource_connection"
-        )
-        self.get_resource_connection_facts = (
-            self.mock_get_resource_connection_facts.start()
+            "ansible_collections.ansible.netcommon.plugins.module_utils.network.common.facts.facts.get_resource_connection",
         )
+        self.get_resource_connection_facts = self.mock_get_resource_connection_facts.start()
 
         self.mock_edit_config = patch(
-            "ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.config.telemetry.telemetry.Telemetry.edit_config"
+            "ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.config.telemetry.telemetry.Telemetry.edit_config",
         )
         self.edit_config = self.mock_edit_config.start()
 
         self.mock_execute_show_command = patch(
-            "ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.nxos.NxosCmdRef.execute_show_command"
+            "ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.nxos.NxosCmdRef.execute_show_command",
         )
         self.execute_show_command = self.mock_execute_show_command.start()
 
         self.mock_get_platform_shortname = patch(
-            "ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.nxos.NxosCmdRef.get_platform_shortname"
+            "ansible_collections.cisco.nxos.plugins.module_utils.network.nxos.nxos.NxosCmdRef.get_platform_shortname",
         )
         self.get_platform_shortname = self.mock_get_platform_shortname.start()
 
@@ -122,7 +113,7 @@ class TestNxosTelemetryModule(TestNxosModule):
                     compression="gzip",
                     source_interface="Ethernet2/1",
                     vrf="blue",
-                )
+                ),
             ),
             ignore_provider_arg,
         )
@@ -193,7 +184,8 @@ class TestNxosTelemetryModule(TestNxosModule):
         # Assumes feature telemetry is enabled
         # TMS global config is present.
         self.execute_show_command.return_value = load_fixture(
-            "nxos_telemetry", "N9K.cfg"
+            "nxos_telemetry",
+            "N9K.cfg",
         )
         self.get_platform_shortname.return_value = "N9K"
         set_module_args(
@@ -206,7 +198,7 @@ class TestNxosTelemetryModule(TestNxosModule):
                     compression="gzip",
                     source_interface="loopback55",
                     vrf="management",
-                )
+                ),
             ),
             ignore_provider_arg,
         )
@@ -217,7 +209,8 @@ class TestNxosTelemetryModule(TestNxosModule):
         # TMS global config is present
         # Change certificate
         self.execute_show_command.return_value = load_fixture(
-            "nxos_telemetry", "N9K.cfg"
+            "nxos_telemetry",
+            "N9K.cfg",
         )
         self.get_platform_shortname.return_value = "N9K"
         set_module_args(
@@ -230,7 +223,7 @@ class TestNxosTelemetryModule(TestNxosModule):
                     compression="gzip",
                     source_interface="loopback55",
                     vrf="management",
-                )
+                ),
             ),
             ignore_provider_arg,
         )
@@ -247,7 +240,8 @@ class TestNxosTelemetryModule(TestNxosModule):
         # TMS global config is present
         # Change interface
         self.execute_show_command.return_value = load_fixture(
-            "nxos_telemetry", "N9K.cfg"
+            "nxos_telemetry",
+            "N9K.cfg",
         )
         self.get_platform_shortname.return_value = "N9K"
         set_module_args(
@@ -260,7 +254,7 @@ class TestNxosTelemetryModule(TestNxosModule):
                     compression="gzip",
                     source_interface="Ethernet8/1",
                     vrf="management",
-                )
+                ),
             ),
             ignore_provider_arg,
         )
@@ -278,7 +272,8 @@ class TestNxosTelemetryModule(TestNxosModule):
         # TMS global config is present
         # Change source_interface, vrf and cert
         self.execute_show_command.return_value = load_fixture(
-            "nxos_telemetry", "N9K.cfg"
+            "nxos_telemetry",
+            "N9K.cfg",
         )
         self.get_platform_shortname.return_value = "N9K"
         set_module_args(
@@ -291,7 +286,7 @@ class TestNxosTelemetryModule(TestNxosModule):
                     compression="gzip",
                     source_interface="Ethernet8/1",
                     vrf="blue",
-                )
+                ),
             ),
             ignore_provider_arg,
         )
@@ -322,8 +317,8 @@ class TestNxosTelemetryModule(TestNxosModule):
                         "port": "5001",
                         "protocol": "GRPC",
                         "encoding": "GPB",
-                    }
-                }
+                    },
+                },
             ],
             "destination_groups",
         )
@@ -332,7 +327,7 @@ class TestNxosTelemetryModule(TestNxosModule):
             self.execute_module()
         testdata = errinfo.value.args[0]
         assert "Parameter <id> under <destination_groups> is required" in str(
-            testdata["msg"]
+            testdata["msg"],
         )
         assert testdata["failed"]
 
@@ -341,15 +336,15 @@ class TestNxosTelemetryModule(TestNxosModule):
         self.execute_show_command.return_value = None
         self.get_platform_shortname.return_value = "N9K"
         args = build_args(
-            [{"id": "88", "destination": "192.168.1.1"}], "destination_groups"
+            [{"id": "88", "destination": "192.168.1.1"}],
+            "destination_groups",
         )
         set_module_args(args, ignore_provider_arg)
         with pytest.raises(AnsibleFailJson) as errinfo:
             self.execute_module()
         testdata = errinfo.value.args[0]
-        assert (
-            "Parameter <destination> under <destination_groups> must be a dict"
-            in str(testdata["msg"])
+        assert "Parameter <destination> under <destination_groups> must be a dict" in str(
+            testdata["msg"],
         )
         assert testdata["failed"]
 
@@ -366,7 +361,7 @@ class TestNxosTelemetryModule(TestNxosModule):
             self.execute_module()
         testdata = errinfo.value.args[0]
         assert "Playbook entry contains unrecongnized parameters" in str(
-            testdata["msg"]
+            testdata["msg"],
         )
         assert testdata["failed"]
 
@@ -446,7 +441,7 @@ class TestNxosTelemetryModule(TestNxosModule):
                         "protocol": "GRPC",
                         "encoding": "GPB",
                     },
-                }
+                },
             ],
             "destination_groups",
             state="merged",
@@ -485,7 +480,8 @@ class TestNxosTelemetryModule(TestNxosModule):
         # TMS destgroup config is not present.
         # Configure only identifier
         self.execute_show_command.return_value = load_fixture(
-            "nxos_telemetry", "N9K.cfg"
+            "nxos_telemetry",
+            "N9K.cfg",
         )
         self.get_platform_shortname.return_value = "N9K"
         args = build_args(
@@ -498,7 +494,7 @@ class TestNxosTelemetryModule(TestNxosModule):
                         "protocol": "grpc",
                         "encoding": "gpb",
                     },
-                }
+                },
             ],
             "destination_groups",
         )
@@ -510,7 +506,8 @@ class TestNxosTelemetryModule(TestNxosModule):
         # TMS destgroup config is not present.
         # Configure only identifier
         self.execute_show_command.return_value = load_fixture(
-            "nxos_telemetry", "N9K.cfg"
+            "nxos_telemetry",
+            "N9K.cfg",
         )
         self.get_platform_shortname.return_value = "N9K"
         args = build_args([{"id": "2"}], "destination_groups")
@@ -521,7 +518,8 @@ class TestNxosTelemetryModule(TestNxosModule):
         # Assumes feature telemetry is enabled
         # TMS destgroup config is present.
         self.execute_show_command.return_value = load_fixture(
-            "nxos_telemetry", "N9K.cfg"
+            "nxos_telemetry",
+            "N9K.cfg",
         )
         self.get_platform_shortname.return_value = "N9K"
         args = build_args(
@@ -554,7 +552,8 @@ class TestNxosTelemetryModule(TestNxosModule):
         # TMS destgroup config is not present.
         # Change protocol and encoding for dest group 2
         self.execute_show_command.return_value = load_fixture(
-            "nxos_telemetry", "N9K.cfg"
+            "nxos_telemetry",
+            "N9K.cfg",
         )
         self.get_platform_shortname.return_value = "N9K"
         args = build_args(
@@ -595,7 +594,8 @@ class TestNxosTelemetryModule(TestNxosModule):
         # Add destinations to destgroup 10
         # Add new destgroup 55 and 56
         self.execute_show_command.return_value = load_fixture(
-            "nxos_telemetry", "N9K.cfg"
+            "nxos_telemetry",
+            "N9K.cfg",
         )
         self.get_platform_shortname.return_value = "N9K"
         args = build_args(
@@ -653,12 +653,8 @@ class TestNxosTelemetryModule(TestNxosModule):
         # TMS sensorgroup config is not present.
         self.execute_show_command.return_value = None
         self.get_platform_shortname.return_value = "N9K"
-        td55_name = (
-            "sys/bgp/inst/dom-default/peer-[10.10.10.11]/ent-[10.10.10.11]"
-        )
-        td55_fc = (
-            'or(eq(ethpmPhysIf.operSt,"down"),eq(ethpmPhysIf.operSt,"up"))'
-        )
+        td55_name = "sys/bgp/inst/dom-default/peer-[10.10.10.11]/ent-[10.10.10.11]"
+        td55_fc = 'or(eq(ethpmPhysIf.operSt,"down"),eq(ethpmPhysIf.operSt,"up"))'
         args = build_args(
             [
                 {
@@ -735,7 +731,7 @@ class TestNxosTelemetryModule(TestNxosModule):
                         "query_condition": "query_condition_xyz",
                         "filter_condition": "filter_condition_xyz",
                     },
-                }
+                },
             ],
             "sensor_groups",
         )
@@ -744,7 +740,7 @@ class TestNxosTelemetryModule(TestNxosModule):
             self.execute_module()
         testdata = errinfo.value.args[0]
         assert "Parameter <id> under <sensor_groups> is required" in str(
-            testdata["msg"]
+            testdata["msg"],
         )
         assert testdata["failed"]
 
@@ -762,7 +758,7 @@ class TestNxosTelemetryModule(TestNxosModule):
                         "query_condition": "query_condition_xyz",
                         "filter_condition": "filter_condition_xyz",
                     },
-                }
+                },
             ],
             "sensor_groups",
         )
@@ -770,9 +766,8 @@ class TestNxosTelemetryModule(TestNxosModule):
         with pytest.raises(AnsibleFailJson) as errinfo:
             self.execute_module()
         testdata = errinfo.value.args[0]
-        assert (
-            "Parameter <path> under <sensor_groups> requires <name> key"
-            in str(testdata["msg"])
+        assert "Parameter <path> under <sensor_groups> requires <name> key" in str(
+            testdata["msg"],
         )
         assert testdata["failed"]
 
@@ -819,7 +814,7 @@ class TestNxosTelemetryModule(TestNxosModule):
                     "id": "77",
                     "data_source": "DME",
                     "path": {"name": "sys/bgp", "depth": 0},
-                }
+                },
             ],
             "sensor_groups",
         )
@@ -850,7 +845,7 @@ class TestNxosTelemetryModule(TestNxosModule):
                         "depth": 0,
                         "query_condition": "query_condition_xyz",
                     },
-                }
+                },
             ],
             "sensor_groups",
         )
@@ -881,7 +876,7 @@ class TestNxosTelemetryModule(TestNxosModule):
                         "depth": 0,
                         "filter_condition": "filter_condition_xyz",
                     },
-                }
+                },
             ],
             "sensor_groups",
         )
@@ -901,7 +896,8 @@ class TestNxosTelemetryModule(TestNxosModule):
         # Assumes feature telemetry is enabled
         # TMS sensorgroup config is not present.
         self.execute_show_command.return_value = load_fixture(
-            "nxos_telemetry", "N9K.cfg"
+            "nxos_telemetry",
+            "N9K.cfg",
         )
         self.get_platform_shortname.return_value = "N9K"
         args = build_args(
@@ -915,7 +911,7 @@ class TestNxosTelemetryModule(TestNxosModule):
                         "query_condition": "qc",
                         "filter_condition": "fc",
                     },
-                }
+                },
             ],
             "sensor_groups",
         )
@@ -926,7 +922,8 @@ class TestNxosTelemetryModule(TestNxosModule):
         # Assumes feature telemetry is enabled
         # TMS sensorgroup config is present with quotes in NX-API path.
         self.execute_show_command.return_value = load_fixture(
-            "nxos_telemetry", "N9K_SGs.cfg"
+            "nxos_telemetry",
+            "N9K_SGs.cfg",
         )
         self.get_platform_shortname.return_value = "N9K"
         args = build_args(
@@ -954,7 +951,8 @@ class TestNxosTelemetryModule(TestNxosModule):
     def test_tms_sensorgroup_vxlan_idempotent_n9k(self):
         # TMS sensorgroup config present.
         self.execute_show_command.return_value = load_fixture(
-            "nxos_telemetry", "N9K.cfg"
+            "nxos_telemetry",
+            "N9K.cfg",
         )
         self.get_platform_shortname.return_value = "N9K"
         args = build_args(
@@ -967,7 +965,8 @@ class TestNxosTelemetryModule(TestNxosModule):
     def test_tms_sensorgroup_idempotent_variable1_n9k(self):
         # TMS sensorgroup config is present with path key name.
         self.execute_show_command.return_value = load_fixture(
-            "nxos_telemetry", "N9K.cfg"
+            "nxos_telemetry",
+            "N9K.cfg",
         )
         self.get_platform_shortname.return_value = "N9K"
         args = build_args(
@@ -976,9 +975,9 @@ class TestNxosTelemetryModule(TestNxosModule):
                     "id": "2",
                     "data_source": "DME",
                     "path": {
-                        "name": "sys/bgp/inst/dom-default/peer-[10.10.10.11]/ent-[10.10.10.11]"
+                        "name": "sys/bgp/inst/dom-default/peer-[10.10.10.11]/ent-[10.10.10.11]",
                     },
-                }
+                },
             ],
             "sensor_groups",
         )
@@ -988,7 +987,8 @@ class TestNxosTelemetryModule(TestNxosModule):
     def test_tms_sensorgroup_idempotent_variable2_n9k(self):
         # TMS sensorgroup config is present with path key name and depth.
         self.execute_show_command.return_value = load_fixture(
-            "nxos_telemetry", "N9K.cfg"
+            "nxos_telemetry",
+            "N9K.cfg",
         )
         self.get_platform_shortname.return_value = "N9K"
         args = build_args(
@@ -997,7 +997,7 @@ class TestNxosTelemetryModule(TestNxosModule):
                     "id": "2",
                     "data_source": "DME",
                     "path": {"name": "boo", "depth": 0},
-                }
+                },
             ],
             "sensor_groups",
         )
@@ -1007,7 +1007,8 @@ class TestNxosTelemetryModule(TestNxosModule):
     def test_tms_sensorgroup_idempotent_resource_key_n9k(self):
         # TMS sensorgroup config is present resource key only.
         self.execute_show_command.return_value = load_fixture(
-            "nxos_telemetry", "N9K.cfg"
+            "nxos_telemetry",
+            "N9K.cfg",
         )
         self.get_platform_shortname.return_value = "N9K"
         args = build_args([{"id": "55"}], "sensor_groups")
@@ -1025,7 +1026,7 @@ class TestNxosTelemetryModule(TestNxosModule):
                     "id": "77",
                     "data_source": "YANG",
                     "path": {"name": "environment"},
-                }
+                },
             ],
             "sensor_groups",
         )
@@ -1052,7 +1053,7 @@ class TestNxosTelemetryModule(TestNxosModule):
                     "id": "77",
                     "data_source": "NATIVE",
                     "path": {"name": "interface"},
-                }
+                },
             ],
             "sensor_groups",
         )
@@ -1068,7 +1069,7 @@ class TestNxosTelemetryModule(TestNxosModule):
             ],
         )
 
-    def test_tms_sensorgroup_present_path_interface_n9k(self):
+    def test_tms_sensorgroup_present_path_interface_n9k_1(self):
         # TMS sensorgroup config is not present.
         # Path name 'resources' test
         self.execute_show_command.return_value = None
@@ -1079,7 +1080,7 @@ class TestNxosTelemetryModule(TestNxosModule):
                     "id": "77",
                     "data_source": "NX-API",
                     "path": {"name": "resources"},
-                }
+                },
             ],
             "sensor_groups",
         )
@@ -1136,7 +1137,8 @@ class TestNxosTelemetryModule(TestNxosModule):
     def test_tms_subscription_merged_idempotent_n9k(self):
         # TMS subscription config is not present.
         self.execute_show_command.return_value = load_fixture(
-            "nxos_telemetry", "N9K.cfg"
+            "nxos_telemetry",
+            "N9K.cfg",
         )
         self.get_platform_shortname.return_value = "N9K"
         args = build_args(
@@ -1162,7 +1164,8 @@ class TestNxosTelemetryModule(TestNxosModule):
         # TMS subscription config present.
         # Change sample interval for sensor group 2
         self.execute_show_command.return_value = load_fixture(
-            "nxos_telemetry", "N9K.cfg"
+            "nxos_telemetry",
+            "N9K.cfg",
         )
         self.get_platform_shortname.return_value = "N9K"
         args = build_args(
@@ -1195,7 +1198,8 @@ class TestNxosTelemetryModule(TestNxosModule):
         # TMS subscription config present.
         # Add new destination_group and sensor_group to subscription 5
         self.execute_show_command.return_value = load_fixture(
-            "nxos_telemetry", "N9K.cfg"
+            "nxos_telemetry",
+            "N9K.cfg",
         )
         self.get_platform_shortname.return_value = "N9K"
         args = build_args(
@@ -1384,7 +1388,8 @@ class TestNxosTelemetryModule(TestNxosModule):
     def test_telemetry_deleted_input_validation_n9k(self):
         # State is 'deleted' and 'config' key present.
         self.execute_show_command.return_value = load_fixture(
-            "nxos_telemetry", "N9K.cfg"
+            "nxos_telemetry",
+            "N9K.cfg",
         )
         self.get_platform_shortname.return_value = "N9K"
         set_module_args(
@@ -1405,9 +1410,8 @@ class TestNxosTelemetryModule(TestNxosModule):
         with pytest.raises(AnsibleFailJson) as errinfo:
             self.execute_module()
         testdata = errinfo.value.args[0]
-        assert (
-            "Remove config key from playbook when state is <deleted>"
-            in str(testdata["msg"])
+        assert "Remove config key from playbook when state is <deleted>" in str(
+            testdata["msg"],
         )
         assert testdata["failed"]
 
@@ -1416,7 +1420,8 @@ class TestNxosTelemetryModule(TestNxosModule):
         # TMS global config is present.
         # Make absent with all playbook keys provided
         self.execute_show_command.return_value = load_fixture(
-            "nxos_telemetry", "N9K.cfg"
+            "nxos_telemetry",
+            "N9K.cfg",
         )
         self.get_platform_shortname.return_value = "N9K"
         set_module_args(dict(state="deleted"), ignore_provider_arg)
@@ -1435,7 +1440,8 @@ class TestNxosTelemetryModule(TestNxosModule):
         # Assumes feature telemetry is enabled
         # Modify global config and remove everything else
         self.execute_show_command.return_value = load_fixture(
-            "nxos_telemetry", "N9K.cfg"
+            "nxos_telemetry",
+            "N9K.cfg",
         )
         self.get_platform_shortname.return_value = "N9K"
         set_module_args(
@@ -1480,7 +1486,8 @@ class TestNxosTelemetryModule(TestNxosModule):
         # Modify sensor-group 55, 56
         # remove all subscriptions
         self.execute_show_command.return_value = load_fixture(
-            "nxos_telemetry", "N9K.cfg"
+            "nxos_telemetry",
+            "N9K.cfg",
         )
         self.get_platform_shortname.return_value = "N9K"
         set_module_args(
@@ -1598,7 +1605,8 @@ class TestNxosTelemetryModule(TestNxosModule):
         # Modify sensor-group 55 and delete all others
         # Modify subscription 7, add 10 and delete all others
         self.execute_show_command.return_value = load_fixture(
-            "nxos_telemetry", "N9K.cfg"
+            "nxos_telemetry",
+            "N9K.cfg",
         )
         self.get_platform_shortname.return_value = "N9K"
         set_module_args(
@@ -1615,7 +1623,7 @@ class TestNxosTelemetryModule(TestNxosModule):
                                 "protocol": "GRPC",
                                 "encoding": "GPB",
                             },
-                        }
+                        },
                     ],
                     "sensor_groups": [
                         {
@@ -1627,7 +1635,7 @@ class TestNxosTelemetryModule(TestNxosModule):
                                 "query_condition": "query_condition_xyz",
                                 "filter_condition": "filter_condition_xyz",
                             },
-                        }
+                        },
                     ],
                     "subscriptions": [
                         {
@@ -1691,7 +1699,8 @@ class TestNxosTelemetryModule(TestNxosModule):
         # Modify sensor-group 55 and delete all others
         # Modify subscription 7, add 10 and delete all others
         self.execute_show_command.return_value = load_fixture(
-            "nxos_telemetry", "N9K.cfg"
+            "nxos_telemetry",
+            "N9K.cfg",
         )
         self.get_platform_shortname.return_value = "N9K"
         set_module_args(
@@ -1772,13 +1781,13 @@ class TestNxosTelemetryModule(TestNxosModule):
                         {
                             "id": 2,
                             "path": {
-                                "name": "sys/bgp/inst/dom-default/peer-[10.10.10.11]/ent-[10.10.10.11]"
+                                "name": "sys/bgp/inst/dom-default/peer-[10.10.10.11]/ent-[10.10.10.11]",
                             },
                         },
                         {
                             "id": 2,
                             "path": {
-                                "name": "sys/bgp/inst/dom-default/peer-[20.20.20.11]/ent-[20.20.20.11]"
+                                "name": "sys/bgp/inst/dom-default/peer-[20.20.20.11]/ent-[20.20.20.11]",
                             },
                         },
                         {
@@ -1833,7 +1842,7 @@ class TestNxosTelemetryModule(TestNxosModule):
           destination-group 2
             ip address 192.168.0.1 port 50001 protocol gRPC encoding GPB
             ip address 192.168.0.2 port 60001 protocol gRPC encoding GPB
-        """
+        """,
         )
         self.get_platform_shortname.return_value = "N9K"
         set_module_args(dict(state="gathered"), ignore_provider_arg)
@@ -1871,6 +1880,218 @@ class TestNxosTelemetryModule(TestNxosModule):
         result = self.execute_module(changed=False)
         self.assertEqual(result["gathered"], gathered)
 
+    def test_tms_names(self):
+        # TMS input with strings
+        self.execute_show_command.return_value = ""
+        self.get_platform_shortname.return_value = "N9K"
+        set_module_args(
+            dict(
+                config=dict(
+                    destination_groups=[
+                        dict(
+                            id="collector",
+                            destination=dict(
+                                ip="192.168.1.100",
+                                port=50051,
+                                protocol="gRPC",
+                                encoding="GPB",
+                            ),
+                        ),
+                    ],
+                    sensor_groups=[
+                        dict(
+                            id="dme_bgp",
+                            data_source="DME",
+                            path=dict(
+                                name="sys/bd",
+                                depth="unbounded",
+                            ),
+                        ),
+                    ],
+                    subscriptions=[
+                        dict(
+                            id="collector_sub",
+                            destination_group="collector",
+                            sensor_group=dict(
+                                id="dme_bgp",
+                                sample_interval=1000,
+                            ),
+                        ),
+                    ],
+                ),
+                state="merged",
+            ),
+            ignore_provider_arg,
+        )
+        self.execute_module(
+            changed=True,
+            commands=[
+                "feature telemetry",
+                "telemetry",
+                "destination-group collector",
+                "ip address 192.168.1.100 port 50051 protocol grpc encoding gpb",
+                "sensor-group dme_bgp",
+                "data-source DME",
+                "path sys/bd depth unbounded",
+                "subscription collector_sub",
+                "dst-grp collector",
+                "snsr-grp dme_bgp sample-interval 1000",
+            ],
+        )
+
+    def test_tms_names_idempotent(self):
+        # TMS input with strings
+        self.execute_show_command.return_value = dedent(
+            """\
+            feature telemetry
+            telemetry
+              destination-group collector
+                ip address 192.168.1.100 port 50051 protocol grpc encoding gpb
+              sensor-group dme_bgp
+                data-source DME
+                path sys/bd depth unbounded
+              subscription collector_sub
+                dst-grp collector
+                snsr-grp dme_bgp sample-interval 1000
+            """,
+        )
+        self.get_platform_shortname.return_value = "N9K"
+        set_module_args(
+            dict(
+                config=dict(
+                    destination_groups=[
+                        dict(
+                            id="collector",
+                            destination=dict(
+                                ip="192.168.1.100",
+                                port=50051,
+                                protocol="gRPC",
+                                encoding="GPB",
+                            ),
+                        ),
+                    ],
+                    sensor_groups=[
+                        dict(
+                            id="dme_bgp",
+                            data_source="DME",
+                            path=dict(
+                                name="sys/bd",
+                                depth="unbounded",
+                            ),
+                        ),
+                    ],
+                    subscriptions=[
+                        dict(
+                            id="collector_sub",
+                            destination_group="collector",
+                            sensor_group=dict(
+                                id="dme_bgp",
+                                sample_interval=1000,
+                            ),
+                        ),
+                    ],
+                ),
+                state="merged",
+            ),
+            ignore_provider_arg,
+        )
+        self.execute_module(changed=False, commands=[])
+
+    def test_tms_overridden_n9k(self):
+        # Assumes feature telemetry is enabled
+        # Similar to replaced state:
+        # - Modify vrf global config, remove default all other global config.
+        # - destination-group 2 destination '192.168.0.1' idempotent
+        # - destination-group 2 destination '192.168.0.2' remove
+        # - remove all other destination-groups
+        # - Modify sensor-group 55 and delete all others
+        # - Modify subscription 7, add 10 and delete all others
+        self.execute_show_command.return_value = load_fixture(
+            "nxos_telemetry",
+            "N9K.cfg",
+        )
+        self.get_platform_shortname.return_value = "N9K"
+        set_module_args(
+            {
+                "state": "overridden",
+                "config": {
+                    "vrf": "blue",
+                    "destination_groups": [
+                        {
+                            "id": 2,
+                            "destination": {
+                                "ip": "192.168.0.1",
+                                "port": 50001,
+                                "protocol": "GRPC",
+                                "encoding": "GPB",
+                            },
+                        },
+                    ],
+                    "sensor_groups": [
+                        {
+                            "id": 55,
+                            "data_source": "NX-API",
+                            "path": {
+                                "name": "sys/bgp",
+                                "depth": 0,
+                                "query_condition": "query_condition_xyz",
+                                "filter_condition": "filter_condition_xyz",
+                            },
+                        },
+                    ],
+                    "subscriptions": [
+                        {
+                            "id": 7,
+                            "destination_group": 10,
+                            "sensor_group": {
+                                "id": 55,
+                                "sample_interval": 1000,
+                            },
+                        },
+                        {
+                            "id": 10,
+                            "destination_group": 2,
+                            "sensor_group": {
+                                "id": 55,
+                                "sample_interval": 1000,
+                            },
+                        },
+                    ],
+                },
+            },
+            ignore_provider_arg,
+        )
+        self.execute_module(
+            changed=True,
+            commands=[
+                "telemetry",
+                "no subscription 3",
+                "no subscription 5",
+                "no subscription 4",
+                "subscription 7",
+                "no snsr-grp 2 sample-interval 1000",
+                "no subscription 6",
+                "no sensor-group 56",
+                "no sensor-group 2",
+                "no destination-group 10",
+                "destination-group 2",
+                "no ip address 192.168.0.2 port 60001 protocol grpc encoding gpb",
+                "sensor-group 55",
+                "data-source NX-API",
+                "path sys/bgp depth 0 query-condition query_condition_xyz filter-condition filter_condition_xyz",
+                "subscription 10",
+                "dst-grp 2",
+                "snsr-grp 55 sample-interval 1000",
+                "subscription 7",
+                "snsr-grp 55 sample-interval 1000",
+                "no certificate /bootflash/server.key localhost",
+                "destination-profile",
+                "no use-compression gzip",
+                "no source-interface loopback55",
+                "use-vrf blue",
+            ],
+        )
+
 
 def build_args(data, type, state=None, check_mode=None):
     if state is None:
