@@ -1,14 +1,9 @@
 #!/usr/bin/python
-# -*- coding: utf-8 -*-
-
 # Copyright (c) 2024 Felix Fontein <felix@fontein.de>
 # GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
 # SPDX-License-Identifier: GPL-3.0-or-later
 
-from __future__ import absolute_import, division, print_function
-
-
-__metaclass__ = type
+from __future__ import annotations
 
 
 DOCUMENTATION = """
@@ -85,11 +80,11 @@ seealso:
   - module: community.crypto.acme_inspect
     description: Allows to debug problems.
 extends_documentation_fragment:
-  - community.crypto.acme.basic
-  - community.crypto.acme.account
-  - community.crypto.acme.certificate
-  - community.crypto.attributes
-  - community.crypto.attributes.actiongroup_acme
+  - community.crypto._acme.basic
+  - community.crypto._acme.account
+  - community.crypto._acme.certificate
+  - community.crypto._attributes
+  - community.crypto._attributes.actiongroup_acme
 attributes:
   check_mode:
     support: none
@@ -215,7 +210,6 @@ EXAMPLES = r"""
 - name: Create a challenge for sample.com using a account key file.
   community.crypto.acme_certificate_order_create:
     acme_directory: https://acme-v01.api.letsencrypt.org/directory
-    acme_version: 2
     account_key_src: /etc/pki/cert/private/account.key
     csr: /etc/pki/cert/csr/sample.com.csr
   register: sample_com_challenge
@@ -238,7 +232,6 @@ EXAMPLES = r"""
 - name: Let the challenge be validated
   community.crypto.acme_certificate_order_validate:
     acme_directory: https://acme-v01.api.letsencrypt.org/directory
-    acme_version: 2
     account_key_src: /etc/pki/cert/private/account.key
     order_uri: "{{ sample_com_challenge.order_uri }}"
     challenge: dns-01
@@ -246,7 +239,6 @@ EXAMPLES = r"""
 - name: Retrieve the cert and intermediate certificate
   community.crypto.acme_certificate_order_finalize:
     acme_directory: https://acme-v01.api.letsencrypt.org/directory
-    acme_version: 2
     account_key_src: /etc/pki/cert/private/account.key
     csr: /etc/pki/cert/csr/sample.com.csr
     order_uri: "{{ sample_com_challenge.order_uri }}"
@@ -379,39 +371,39 @@ account_uri:
   type: str
 """
 
-from ansible_collections.community.crypto.plugins.module_utils.acme.acme import (
+import typing as t
+
+from ansible_collections.community.crypto.plugins.module_utils._acme.acme import (
     create_backend,
     create_default_argspec,
 )
-from ansible_collections.community.crypto.plugins.module_utils.acme.certificate import (
+from ansible_collections.community.crypto.plugins.module_utils._acme.certificate import (
     ACMECertificateClient,
 )
-from ansible_collections.community.crypto.plugins.module_utils.acme.errors import (
+from ansible_collections.community.crypto.plugins.module_utils._acme.errors import (
     ModuleFailException,
 )
 
 
-def main():
+def main() -> t.NoReturn:
     argument_spec = create_default_argspec(with_certificate=True)
     argument_spec.update_argspec(
-        deactivate_authzs=dict(type="bool", default=True),
-        replaces_cert_id=dict(type="str"),
-        profile=dict(type="str"),
-        order_creation_error_strategy=dict(
-            type="str",
-            default="auto",
-            choices=["auto", "always", "fail", "retry_without_replaces_cert_id"],
-        ),
-        order_creation_max_retries=dict(type="int", default=3),
+        deactivate_authzs={"type": "bool", "default": True},
+        replaces_cert_id={"type": "str"},
+        profile={"type": "str"},
+        order_creation_error_strategy={
+            "type": "str",
+            "default": "auto",
+            "choices": ["auto", "always", "fail", "retry_without_replaces_cert_id"],
+        },
+        order_creation_max_retries={"type": "int", "default": 3},
     )
     module = argument_spec.create_ansible_module()
-    if module.params["acme_version"] == 1:
-        module.fail_json("The module does not support acme_version=1")
 
-    backend = create_backend(module, False)
+    backend = create_backend(module, needs_acme_v2=False)
 
     try:
-        client = ACMECertificateClient(module, backend)
+        client = ACMECertificateClient(module=module, backend=backend)
 
         profile = module.params["profile"]
         if profile is not None:
@@ -424,9 +416,7 @@ def main():
                 )
             if profile not in meta_profiles:
                 raise ModuleFailException(
-                    msg="The ACME CA does not support selected profile {0!r}.".format(
-                        profile
-                    )
+                    msg=f"The ACME CA does not support selected profile {profile!r}."
                 )
 
         order = None
@@ -449,7 +439,7 @@ def main():
             challenge_data_dns=data_dns,
         )
     except ModuleFailException as e:
-        e.do_fail(module)
+        e.do_fail(module=module)
 
 
 if __name__ == "__main__":
