@@ -6,6 +6,7 @@
 # Make coding more python3-ish
 from __future__ import absolute_import, division, print_function
 
+
 __metaclass__ = type
 
 
@@ -15,25 +16,29 @@ from ansible_collections.community.dns.plugins.module_utils.provider import (
 
 
 class CustomProviderInformation(ProviderInformation):
-    def __init__(self, txt_record_handling='decoded'):
+    def __init__(self, txt_record_handling='decoded', txt_character_encoding='decimal'):
         super(CustomProviderInformation, self).__init__()
         self._txt_record_handling = txt_record_handling
+        self._txt_character_encoding = txt_character_encoding
 
     def get_supported_record_types(self):
         return ['A']
 
     def get_zone_id_type(self):
-        return 'str'
+        return 'str'  # pragma: no cover
 
     def get_record_id_type(self):
-        return 'str'
+        return 'str'  # pragma: no cover
 
     def get_record_default_ttl(self):
-        return 300
+        return 300  # pragma: no cover
 
     def txt_record_handling(self):
         return self._txt_record_handling
 
+    def txt_character_encoding(self):
+        return self._txt_character_encoding
+
 
 class CustomProvideOptions(object):
     def __init__(self, option_dict):
