@@ -1,193 +1,189 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 
-# Copyright: (c) 2014, Kevin Carter <kevin.carter@rackspace.com>
-# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
+# Copyright (c) 2014, Kevin Carter <kevin.carter@rackspace.com>
+# GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 from __future__ import absolute_import, division, print_function
 __metaclass__ = type
 
 
-DOCUMENTATION = r'''
----
+DOCUMENTATION = r"""
 module: lxc_container
 short_description: Manage LXC Containers
 description:
   - Management of LXC containers.
 author: "Kevin Carter (@cloudnull)"
+extends_documentation_fragment:
+  - community.general.attributes
+attributes:
+  check_mode:
+    support: none
+  diff_mode:
+    support: none
 options:
-    name:
-        description:
-          - Name of a container.
-        type: str
-        required: true
-    backing_store:
-        choices:
-          - dir
-          - lvm
-          - loop
-          - btrfs
-          - overlayfs
-          - zfs
-        description:
-          - Backend storage type for the container.
-        type: str
-        default: dir
-    template:
-        description:
-          - Name of the template to use within an LXC create.
-        type: str
-        default: ubuntu
-    template_options:
-        description:
-          - Template options when building the container.
-        type: str
-    config:
-        description:
-          - Path to the LXC configuration file.
-        type: path
-    lv_name:
-        description:
-          - Name of the logical volume, defaults to the container name.
-          - If not specified, it defaults to C($CONTAINER_NAME).
-        type: str
-    vg_name:
-        description:
-          - If backend store is lvm, specify the name of the volume group.
-        type: str
-        default: lxc
-    thinpool:
-        description:
-          - Use LVM thin pool called TP.
-        type: str
-    fs_type:
-        description:
-          - Create fstype TYPE.
-        type: str
-        default: ext4
-    fs_size:
-        description:
-          - File system Size.
-        type: str
-        default: 5G
-    directory:
-        description:
-          - Place rootfs directory under DIR.
-        type: path
-    zfs_root:
-        description:
-          - Create zfs under given zfsroot.
-        type: str
-    container_command:
-        description:
-          - Run a command within a container.
-        type: str
-    lxc_path:
-        description:
-          - Place container under PATH.
-        type: path
-    container_log:
-        description:
-          - Enable a container log for host actions to the container.
-        type: bool
-        default: 'no'
-    container_log_level:
-        choices:
-          - Info
-          - info
-          - INFO
-          - Error
-          - error
-          - ERROR
-          - Debug
-          - debug
-          - DEBUG
-        description:
-          - Set the log level for a container where *container_log* was set.
-        type: str
-        required: false
-        default: INFO
-    clone_name:
-        description:
-          - Name of the new cloned server.
-          - This is only used when state is clone.
-        type: str
-    clone_snapshot:
-        description:
-          - Create a snapshot a container when cloning.
-          - This is not supported by all container storage backends.
-          - Enabling this may fail if the backing store does not support snapshots.
-        type: bool
-        default: 'no'
-    archive:
-        description:
-          - Create an archive of a container.
-          - This will create a tarball of the running container.
-        type: bool
-        default: 'no'
-    archive_path:
-        description:
-          - Path the save the archived container.
-          - If the path does not exist the archive method will attempt to create it.
-        type: path
-    archive_compression:
-        choices:
-          - gzip
-          - bzip2
-          - none
-        description:
-          - Type of compression to use when creating an archive of a running
-            container.
-        type: str
-        default: gzip
-    state:
-        choices:
-          - started
-          - stopped
-          - restarted
-          - absent
-          - frozen
-          - clone
-        description:
-          - Define the state of a container.
-          - If you clone a container using I(clone_name) the newly cloned
-            container created in a stopped state.
-          - The running container will be stopped while the clone operation is
-            happening and upon completion of the clone the original container
-            state will be restored.
-        type: str
-        default: started
-    container_config:
-        description:
-          - A list of C(key=value) options to use when configuring a container.
-        type: list
-        elements: str
+  name:
+    description:
+      - Name of a container.
+    type: str
+    required: true
+  backing_store:
+    choices:
+      - dir
+      - lvm
+      - loop
+      - btrfs
+      - overlayfs
+      - zfs
+    description:
+      - Backend storage type for the container.
+    type: str
+    default: dir
+  template:
+    description:
+      - Name of the template to use within an LXC create.
+    type: str
+    default: ubuntu
+  template_options:
+    description:
+      - Template options when building the container.
+    type: str
+  config:
+    description:
+      - Path to the LXC configuration file.
+    type: path
+  lv_name:
+    description:
+      - Name of the logical volume, defaults to the container name.
+      - If not specified, it defaults to E(CONTAINER_NAME).
+    type: str
+  vg_name:
+    description:
+      - If backend store is lvm, specify the name of the volume group.
+    type: str
+    default: lxc
+  thinpool:
+    description:
+      - Use LVM thin pool called TP.
+    type: str
+  fs_type:
+    description:
+      - Create fstype TYPE.
+    type: str
+    default: ext4
+  fs_size:
+    description:
+      - File system Size.
+    type: str
+    default: 5G
+  directory:
+    description:
+      - Place rootfs directory under DIR.
+    type: path
+  zfs_root:
+    description:
+      - Create zfs under given zfsroot.
+    type: str
+  container_command:
+    description:
+      - Run a command within a container.
+    type: str
+  lxc_path:
+    description:
+      - Place container under E(PATH).
+    type: path
+  container_log:
+    description:
+      - Enable a container log for host actions to the container.
+    type: bool
+    default: false
+  container_log_level:
+    choices:
+      - Info
+      - info
+      - INFO
+      - Error
+      - error
+      - ERROR
+      - Debug
+      - debug
+      - DEBUG
+    description:
+      - Set the log level for a container where O(container_log) was set.
+    type: str
+    required: false
+    default: INFO
+  clone_name:
+    description:
+      - Name of the new cloned server.
+      - This is only used when state is clone.
+    type: str
+  clone_snapshot:
+    description:
+      - Create a snapshot a container when cloning.
+      - This is not supported by all container storage backends.
+      - Enabling this may fail if the backing store does not support snapshots.
+    type: bool
+    default: false
+  archive:
+    description:
+      - Create an archive of a container.
+      - This creates a tarball of the running container.
+    type: bool
+    default: false
+  archive_path:
+    description:
+      - Path the save the archived container.
+      - If the path does not exist the archive method attempts to create it.
+    type: path
+  archive_compression:
+    choices:
+      - gzip
+      - bzip2
+      - none
+    description:
+      - Type of compression to use when creating an archive of a running container.
+    type: str
+    default: gzip
+  state:
+    choices:
+      - started
+      - stopped
+      - restarted
+      - absent
+      - frozen
+      - clone
+    description:
+      - Define the state of a container.
+      - If you clone a container using O(clone_name) the newly cloned container created in a stopped state.
+      - The running container is stopped while the clone operation is happening and upon completion of the clone the original
+        container state is restored.
+    type: str
+    default: started
+  container_config:
+    description:
+      - A list of C(key=value) options to use when configuring a container.
+    type: list
+    elements: str
 requirements:
-  - 'lxc >= 1.0 # OS package'
-  - 'python >= 2.6 # OS Package'
-  - 'lxc-python2 >= 0.1 # PIP Package from https://github.com/lxc/python2-lxc'
+  - 'lxc >= 2.0 # OS package'
+  - 'python3 >= 3.5 # OS Package'
+  - 'python3-lxc # OS Package'
 notes:
-  - Containers must have a unique name. If you attempt to create a container
-    with a name that already exists in the users namespace the module will
-    simply return as "unchanged".
-  - The "container_command" can be used with any state except "absent". If
-    used with state "stopped" the container will be "started", the command
-    executed, and then the container "stopped" again. Likewise if the state
-    is "stopped" and the container does not exist it will be first created,
-    "started", the command executed, and then "stopped". If you use a "|"
-    in the variable you can use common script formatting within the variable
-    itself The "container_command" option will always execute as BASH.
-    When using "container_command" a log file is created in the /tmp/ directory
-    which contains both stdout and stderr of any command executed.
-  - If "archive" is **true** the system will attempt to create a compressed
-    tarball of the running container. The "archive" option supports LVM backed
-    containers and will create a snapshot of the running container when
-    creating the archive.
-  - If your distro does not have a package for "python2-lxc", which is a
-    requirement for this module, it can be installed from source at
-    "https://github.com/lxc/python2-lxc" or installed via pip using the package
-    name lxc-python2.
-'''
+  - Containers must have a unique name. If you attempt to create a container with a name that already exists in the users
+    namespace the module simply returns as "unchanged".
+  - The O(container_command) can be used with any state except V(absent). If used with state V(stopped) the container is V(started),
+    the command executed, and then the container V(stopped) again. Likewise if O(state=stopped) and the container does not
+    exist it is first created, V(started), the command executed, and then V(stopped). If you use a C(|) in the variable you
+    can use common script formatting within the variable itself. The O(container_command) option always execute as C(bash).
+    When using O(container_command), a log file is created in the C(/tmp/) directory which contains both C(stdout) and C(stderr)
+    of any command executed.
+  - If O(archive=true) the system attempts to create a compressed tarball of the running container. The O(archive) option
+    supports LVM backed containers and creates a snapshot of the running container when creating the archive.
+  - If your distro does not have a package for C(python3-lxc), which is a requirement for this module, it can be installed
+    from source at U(https://github.com/lxc/python3-lxc) or installed using C(pip install lxc).
+"""
 
 EXAMPLES = r"""
 - name: Create a started container
@@ -260,14 +256,14 @@ EXAMPLES = r"""
   ansible.builtin.debug:
     var: lvm_container_info
 
-- name: Run a command in a container and ensure its in a "stopped" state.
+- name: Run a command in a container and ensure it is in a "stopped" state.
   community.general.lxc_container:
     name: test-container-started
     state: stopped
     container_command: |
       echo 'hello world.' | tee /opt/stopped
 
-- name: Run a command in a container and ensure its it in a "frozen" state.
+- name: Run a command in a container and ensure it is in a "frozen" state.
   community.general.lxc_container:
     name: test-container-stopped
     state: frozen
@@ -374,45 +370,45 @@ EXAMPLES = r"""
 
 RETURN = r"""
 lxc_container:
-    description: container information
-    returned: success
-    type: complex
-    contains:
-        name:
-            description: name of the lxc container
-            returned: success
-            type: str
-            sample: test_host
-        init_pid:
-            description: pid of the lxc init process
-            returned: success
-            type: int
-            sample: 19786
-        interfaces:
-            description: list of the container's network interfaces
-            returned: success
-            type: list
-            sample: [ "eth0", "lo" ]
-        ips:
-            description: list of ips
-            returned: success
-            type: list
-            sample: [ "10.0.3.3" ]
-        state:
-            description: resulting state of the container
-            returned: success
-            type: str
-            sample: "running"
-        archive:
-            description: resulting state of the container
-            returned: success, when archive is true
-            type: str
-            sample: "/tmp/test-container-config.tar"
-        clone:
-            description: if the container was cloned
-            returned: success, when clone_name is specified
-            type: bool
-            sample: True
+  description: Container information.
+  returned: success
+  type: complex
+  contains:
+    name:
+      description: Name of the LXC container.
+      returned: success
+      type: str
+      sample: test_host
+    init_pid:
+      description: Pid of the LXC init process.
+      returned: success
+      type: int
+      sample: 19786
+    interfaces:
+      description: List of the container's network interfaces.
+      returned: success
+      type: list
+      sample: ["eth0", "lo"]
+    ips:
+      description: List of IPs.
+      returned: success
+      type: list
+      sample: ["10.0.3.3"]
+    state:
+      description: Resulting state of the container.
+      returned: success
+      type: str
+      sample: "running"
+    archive:
+      description: Resulting state of the container.
+      returned: success, when archive is true
+      type: str
+      sample: "/tmp/test-container-config.tar"
+    clone:
+      description: If the container was cloned.
+      returned: success, when clone_name is specified
+      type: bool
+      sample: true
 """
 
 import os
@@ -422,6 +418,7 @@ import shutil
 import subprocess
 import tempfile
 import time
+import shlex
 
 try:
     import lxc
@@ -431,9 +428,8 @@ else:
     HAS_LXC = True
 
 from ansible.module_utils.basic import AnsibleModule
-from ansible.module_utils.parsing.convert_bool import BOOLEANS_FALSE, BOOLEANS_TRUE
-from ansible.module_utils.six.moves import xrange
-from ansible.module_utils._text import to_text, to_bytes
+from ansible.module_utils.parsing.convert_bool import BOOLEANS_FALSE
+from ansible.module_utils.common.text.converters import to_text, to_bytes
 
 
 # LXC_COMPRESSION_MAP is a map of available compression types when creating
@@ -557,7 +553,7 @@ popd
 def create_script(command):
     """Write out a script onto a target.
 
-    This method should be backward compatible with Python 2.4+ when executing
+    This method should be backward compatible with Python when executing
     from within the container.
 
     :param command: command to run, this can be a script and can use spacing
@@ -606,10 +602,10 @@ class LxcContainerManagement(object):
         :type module: ``object``
         """
         self.module = module
-        self.state = self.module.params.get('state', None)
+        self.state = self.module.params['state']
         self.state_change = False
         self.lxc_vg = None
-        self.lxc_path = self.module.params.get('lxc_path', None)
+        self.lxc_path = self.module.params['lxc_path']
         self.container_name = self.module.params['name']
         self.container = self.get_container_bind()
         self.archive_info = None
@@ -642,10 +638,7 @@ class LxcContainerManagement(object):
         :returns: True or False if the container is found.
         :rtype: ``bol``
         """
-        if [i for i in lxc.list_containers(config_path=lxc_path) if i == container_name]:
-            return True
-        else:
-            return False
+        return any(c == container_name for c in lxc.list_containers(config_path=lxc_path))
 
     @staticmethod
     def _add_variables(variables_dict, build_command):
@@ -661,9 +654,8 @@ class LxcContainerManagement(object):
         """
 
         for key, value in variables_dict.items():
-            build_command.append(
-                '%s %s' % (key, value)
-            )
+            build_command.append(str(key))
+            build_command.append(str(value))
         return build_command
 
     def _get_vars(self, variables):
@@ -678,41 +670,23 @@ class LxcContainerManagement(object):
         for v in LXC_BACKING_STORE[self.module.params['backing_store']]:
             variables.pop(v, None)
 
-        return_dict = dict()
         false_values = BOOLEANS_FALSE.union([None, ''])
-        for k, v in variables.items():
-            _var = self.module.params.get(k)
-            if _var not in false_values:
-                return_dict[v] = _var
-        return return_dict
-
-    def _run_command(self, build_command, unsafe_shell=False):
-        """Return information from running an Ansible Command.
-
-        This will squash the build command list into a string and then
-        execute the command via Ansible. The output is returned to the method.
-        This output is returned as `return_code`, `stdout`, `stderr`.
-
-        :param build_command: Used for the command and all options.
-        :type build_command: ``list``
-        :param unsafe_shell: Enable or Disable unsafe sell commands.
-        :type unsafe_shell: ``bol``
-        """
-
-        return self.module.run_command(
-            ' '.join(build_command),
-            use_unsafe_shell=unsafe_shell
-        )
+        result = {
+            v: self.module.params[k]
+            for k, v in variables.items()
+            if self.module.params[k] not in false_values
+        }
+        return result
 
     def _config(self):
         """Configure an LXC container.
 
         Write new configuration values to the lxc config file. This will
-        stop the container if it's running write the new options and then
+        stop the container if it is running write the new options and then
         restart the container upon completion.
         """
 
-        _container_config = self.module.params.get('container_config')
+        _container_config = self.module.params['container_config']
         if not _container_config:
             return False
 
@@ -802,15 +776,15 @@ class LxcContainerManagement(object):
         )
 
         # Load logging for the instance when creating it.
-        if self.module.params.get('clone_snapshot') in BOOLEANS_TRUE:
+        if self.module.params['clone_snapshot']:
             build_command.append('--snapshot')
         # Check for backing_store == overlayfs if so force the use of snapshot
         # If overlay fs is used and snapshot is unset the clone command will
         # fail with an unsupported type.
-        elif self.module.params.get('backing_store') == 'overlayfs':
+        elif self.module.params['backing_store'] == 'overlayfs':
             build_command.append('--snapshot')
 
-        rc, return_data, err = self._run_command(build_command)
+        rc, return_data, err = self.module.run_command(build_command)
         if rc != 0:
             message = "Failed executing %s." % os.path.basename(clone_cmd)
             self.failure(
@@ -843,7 +817,7 @@ class LxcContainerManagement(object):
 
         build_command = [
             self.module.get_bin_path('lxc-create', True),
-            '--name %s' % self.container_name,
+            '--name', self.container_name,
             '--quiet'
         ]
 
@@ -855,7 +829,7 @@ class LxcContainerManagement(object):
         )
 
         # Load logging for the instance when creating it.
-        if self.module.params.get('container_log') in BOOLEANS_TRUE:
+        if self.module.params['container_log']:
             # Set the logging path to the /var/log/lxc if uid is root. else
             # set it to the home folder of the user executing.
             try:
@@ -869,20 +843,23 @@ class LxcContainerManagement(object):
                 log_path = os.getenv('HOME')
 
             build_command.extend([
-                '--logfile %s' % os.path.join(
+                '--logfile',
+                os.path.join(
                     log_path, 'lxc-%s.log' % self.container_name
                 ),
-                '--logpriority %s' % self.module.params.get(
+                '--logpriority',
+                self.module.params.get(
                     'container_log_level'
                 ).upper()
             ])
 
         # Add the template commands to the end of the command if there are any
-        template_options = self.module.params.get('template_options', None)
+        template_options = self.module.params['template_options']
         if template_options:
-            build_command.append('-- %s' % template_options)
+            build_command.append('--')
+            build_command += shlex.split(template_options)
 
-        rc, return_data, err = self._run_command(build_command)
+        rc, return_data, err = self.module.run_command(build_command)
         if rc != 0:
             message = "Failed executing lxc-create."
             self.failure(
@@ -934,7 +911,7 @@ class LxcContainerManagement(object):
     def _execute_command(self):
         """Execute a shell command."""
 
-        container_command = self.module.params.get('container_command')
+        container_command = self.module.params['container_command']
         if container_command:
             container_state = self._get_state()
             if container_state == 'frozen':
@@ -953,18 +930,17 @@ class LxcContainerManagement(object):
         """
 
         self.container = self.get_container_bind()
-        for dummy in xrange(timeout):
-            if self._get_state() != 'running':
-                self.container.start()
-                self.state_change = True
-                # post startup sleep for 1 second.
-                time.sleep(1)
-            else:
+        for dummy in range(timeout):
+            if self._get_state() == 'running':
                 return True
+
+            self.container.start()
+            self.state_change = True
+            # post startup sleep for 1 second.
+            time.sleep(1)
         self.failure(
             lxc_container=self._container_data(),
-            error='Failed to start container'
-                  ' [ %s ]' % self.container_name,
+            error='Failed to start container [ %s ]' % self.container_name,
             rc=1,
             msg='The container [ %s ] failed to start. Check to lxc is'
                 ' available and that the container is in a functional'
@@ -977,7 +953,7 @@ class LxcContainerManagement(object):
         This will store archive_info in as self.archive_info
         """
 
-        if self.module.params.get('archive') in BOOLEANS_TRUE:
+        if self.module.params['archive']:
             self.archive_info = {
                 'archive': self._container_create_tar()
             }
@@ -988,7 +964,7 @@ class LxcContainerManagement(object):
         This will store archive_info in as self.archive_info
         """
 
-        clone_name = self.module.params.get('clone_name')
+        clone_name = self.module.params['clone_name']
         if clone_name:
             if not self._container_exists(container_name=clone_name, lxc_path=self.lxc_path):
                 self.clone_info = {
@@ -1006,7 +982,7 @@ class LxcContainerManagement(object):
         :type timeout: ``int``
         """
 
-        for dummy in xrange(timeout):
+        for dummy in range(timeout):
             if not self._container_exists(container_name=self.container_name, lxc_path=self.lxc_path):
                 break
 
@@ -1186,7 +1162,7 @@ class LxcContainerManagement(object):
             self.module.get_bin_path('lxc-config', True),
             "lxc.bdev.lvm.vg"
         ]
-        rc, vg, err = self._run_command(build_command)
+        rc, vg, err = self.module.run_command(build_command)
         if rc != 0:
             self.failure(
                 err=err,
@@ -1204,7 +1180,7 @@ class LxcContainerManagement(object):
         build_command = [
             self.module.get_bin_path('lvs', True)
         ]
-        rc, stdout, err = self._run_command(build_command)
+        rc, stdout, err = self.module.run_command(build_command)
         if rc != 0:
             self.failure(
                 err=err,
@@ -1231,7 +1207,7 @@ class LxcContainerManagement(object):
             '--units',
             'g'
         ]
-        rc, stdout, err = self._run_command(build_command)
+        rc, stdout, err = self.module.run_command(build_command)
         if rc != 0:
             self.failure(
                 err=err,
@@ -1262,7 +1238,7 @@ class LxcContainerManagement(object):
             '--units',
             'g'
         ]
-        rc, stdout, err = self._run_command(build_command)
+        rc, stdout, err = self.module.run_command(build_command)
         if rc != 0:
             self.failure(
                 err=err,
@@ -1289,7 +1265,7 @@ class LxcContainerManagement(object):
         """
 
         vg = self._get_lxc_vg()
-        free_space, messurement = self._get_vg_free_pe(vg_name=vg)
+        free_space, measurement = self._get_vg_free_pe(vg_name=vg)
 
         if free_space < float(snapshot_size_gb):
             message = (
@@ -1311,7 +1287,7 @@ class LxcContainerManagement(object):
             os.path.join(vg, source_lv),
             "-L%sg" % snapshot_size_gb
         ]
-        rc, stdout, err = self._run_command(build_command)
+        rc, stdout, err = self.module.run_command(build_command)
         if rc != 0:
             self.failure(
                 err=err,
@@ -1336,7 +1312,7 @@ class LxcContainerManagement(object):
             "/dev/%s/%s" % (vg, lv_name),
             mount_point,
         ]
-        rc, stdout, err = self._run_command(build_command)
+        rc, stdout, err = self.module.run_command(build_command)
         if rc != 0:
             self.failure(
                 err=err,
@@ -1354,11 +1330,11 @@ class LxcContainerManagement(object):
 
         old_umask = os.umask(int('0077', 8))
 
-        archive_path = self.module.params.get('archive_path')
+        archive_path = self.module.params['archive_path']
         if not os.path.isdir(archive_path):
             os.makedirs(archive_path)
 
-        archive_compression = self.module.params.get('archive_compression')
+        archive_compression = self.module.params['archive_compression']
         compression_type = LXC_COMPRESSION_MAP[archive_compression]
 
         # remove trailing / if present.
@@ -1372,17 +1348,14 @@ class LxcContainerManagement(object):
 
         build_command = [
             self.module.get_bin_path('tar', True),
-            '--directory=%s' % os.path.realpath(
-                os.path.expanduser(source_dir)
-            ),
+            '--directory=%s' % os.path.realpath(source_dir),
             compression_type['argument'],
             archive_name,
             '.'
         ]
 
-        rc, stdout, err = self._run_command(
-            build_command=build_command,
-            unsafe_shell=True
+        rc, stdout, err = self.module.run_command(
+            build_command
         )
 
         os.umask(old_umask)
@@ -1410,7 +1383,7 @@ class LxcContainerManagement(object):
             "-f",
             "%s/%s" % (vg, lv_name),
         ]
-        rc, stdout, err = self._run_command(build_command)
+        rc, stdout, err = self.module.run_command(build_command)
         if rc != 0:
             self.failure(
                 err=err,
@@ -1442,11 +1415,10 @@ class LxcContainerManagement(object):
                 self.module.get_bin_path('rsync', True),
                 '-aHAX',
                 fs_path,
-                temp_dir
+                temp_dir,
             ]
-            rc, stdout, err = self._run_command(
+            rc, stdout, err = self.module.run_command(
                 build_command,
-                unsafe_shell=True
             )
             if rc != 0:
                 self.failure(
@@ -1467,7 +1439,7 @@ class LxcContainerManagement(object):
             self.module.get_bin_path('umount', True),
             mount_point,
         ]
-        rc, stdout, err = self._run_command(build_command)
+        rc, stdout, err = self.module.run_command(build_command)
         if rc != 0:
             self.failure(
                 err=err,
@@ -1489,12 +1461,12 @@ class LxcContainerManagement(object):
 
         build_command = [
             self.module.get_bin_path('mount', True),
-            '-t overlayfs',
-            '-o lowerdir=%s,upperdir=%s' % (lowerdir, upperdir),
+            '-t', 'overlayfs',
+            '-o', 'lowerdir=%s,upperdir=%s' % (lowerdir, upperdir),
             'overlayfs',
             mount_point,
         ]
-        rc, stdout, err = self._run_command(build_command)
+        rc, stdout, err = self.module.run_command(build_command)
         if rc != 0:
             self.failure(
                 err=err,
@@ -1719,7 +1691,6 @@ def main():
             ),
             clone_name=dict(
                 type='str',
-                required=False
             ),
             clone_snapshot=dict(
                 type='bool',
@@ -1748,9 +1719,8 @@ def main():
             msg='The `lxc` module is not importable. Check the requirements.'
         )
 
-    lv_name = module.params.get('lv_name')
-    if not lv_name:
-        module.params['lv_name'] = module.params.get('name')
+    if not module.params['lv_name']:
+        module.params['lv_name'] = module.params['name']
 
     lxc_manage = LxcContainerManagement(module=module)
     lxc_manage.run()
