@@ -179,12 +179,12 @@ results:
 
 try:
     from pyVmomi import vim
-    HAS_PYVMOMI = True
 except ImportError:
-    HAS_PYVMOMI = False
+    pass
 
 from ansible.module_utils.basic import AnsibleModule
-from ansible_collections.community.vmware.plugins.module_utils.vmware import PyVmomi, vmware_argument_spec, find_obj
+from ansible_collections.community.vmware.plugins.module_utils.vmware import PyVmomi, find_obj
+from ansible_collections.community.vmware.plugins.module_utils._argument_spec import base_argument_spec
 from ansible.module_utils._text import to_native
 
 
@@ -553,7 +553,7 @@ class VmwareHostSnmp(PyVmomi):
 
 def main():
     """Main"""
-    argument_spec = vmware_argument_spec()
+    argument_spec = base_argument_spec()
     argument_spec.update(
         cluster_name=dict(type='str', required=False),
         esxi_hostname=dict(type='list', elements='str', required=False),
@@ -574,9 +574,6 @@ def main():
         supports_check_mode=True,
     )
 
-    if not HAS_PYVMOMI:
-        module.fail_json(msg='pyvmomi required for this module')
-
     host_snmp = VmwareHostSnmp(module)
     host_snmp.ensure()
 
