@@ -99,20 +99,21 @@ options:
         suboptions:
             host:
                 type: str
-                description: No description.
+                description: Host.
             seq:
                 type: int
-                description: No description.
+                description: Seq.
                 required: true
             subnet:
                 type: str
-                description: No description.
+                description: Subnet.
 '''
 
 EXAMPLES = '''
 - name: Example playbook (generated based on argument schema)
   hosts: fortimanagers
   connection: httpapi
+  gather_facts: false
   vars:
     ansible_httpapi_use_ssl: true
     ansible_httpapi_validate_certs: false
@@ -130,9 +131,9 @@ EXAMPLES = '''
         policy: <your own value>
         state: present # <value in [present, absent]>
         pkg_firewall_policy_vpnsrcnode:
-          host: <string>
-          seq: <integer>
-          subnet: <string>
+          seq: 0 # Required variable, integer
+          # host: <string>
+          # subnet: <string>
 '''
 
 RETURN = '''
@@ -176,21 +177,14 @@ version_check_warning:
 '''
 from ansible.module_utils.basic import AnsibleModule
 from ansible.module_utils.connection import Connection
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_galaxy_version
-from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import check_parameter_bypass
+from ansible_collections.fortinet.fortimanager.plugins.module_utils.napi import NAPIManager, check_galaxy_version, check_parameter_bypass
 from ansible_collections.fortinet.fortimanager.plugins.module_utils.common import get_module_arg_spec
 
 
 def main():
-    jrpc_urls = [
+    urls_list = [
         '/pm/config/adom/{adom}/pkg/{pkg}/firewall/policy/{policy}/vpn_src_node'
     ]
-
-    perobject_jrpc_urls = [
-        '/pm/config/adom/{adom}/pkg/{pkg}/firewall/policy/{policy}/vpn_src_node/{vpn_src_node}'
-    ]
-
     url_params = ['adom', 'pkg', 'policy']
     module_primary_key = 'seq'
     module_arg_spec = {
@@ -205,7 +199,6 @@ def main():
                 'seq': {'v_range': [['6.0.0', '7.0.2']], 'required': True, 'type': 'int'},
                 'subnet': {'v_range': [['6.0.0', '7.0.2']], 'type': 'str'}
             }
-
         }
     }
 
@@ -214,17 +207,15 @@ def main():
     params_validation_blob = []
     check_galaxy_version(module_arg_spec)
     module = AnsibleModule(argument_spec=check_parameter_bypass(module_arg_spec, 'pkg_firewall_policy_vpnsrcnode'),
-                           supports_check_mode=False)
+                           supports_check_mode=True)
 
     if not module._socket_path:
         module.fail_json(msg='MUST RUN IN HTTPAPI MODE')
     connection = Connection(module._socket_path)
-    connection.set_option('access_token', module.params.get('access_token', None))
-    connection.set_option('enable_log', module.params.get('enable_log', False))
-    connection.set_option('forticloud_access_token', module.params.get('forticloud_access_token', None))
-    fmgr = NAPIManager(jrpc_urls, perobject_jrpc_urls, module_primary_key, url_params, module, connection, top_level_schema_name='data')
+    fmgr = NAPIManager('full crud', module_arg_spec, urls_list, module_primary_key, url_params,
+                       module, connection, top_level_schema_name='data')
     fmgr.validate_parameters(params_validation_blob)
-    fmgr.process_curd(argument_specs=module_arg_spec)
+    fmgr.process_crud()
 
     module.exit_json(meta=module.params)
 
