@@ -6,7 +6,7 @@
 #
 # Copyright (c) 2017, Sumit Kumar <sumit4@netapp.com>
 # Copyright (c) 2017, Michael Price <michael.price@netapp.com>
-# Copyright (c) 2017-2023, NetApp, Inc
+# Copyright (c) 2017-2025, NetApp, Inc
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without modification,
@@ -48,7 +48,7 @@ try:
 except ImportError:
     ANSIBLE_VERSION = 'unknown'
 
-COLLECTION_VERSION = "22.4.1"
+COLLECTION_VERSION = "23.1.0"
 CLIENT_APP_VERSION = "%s/%s" % ("%s", COLLECTION_VERSION)
 IMPORT_EXCEPTION = None
 
@@ -108,10 +108,9 @@ ERROR_MSG = dict(
 
 LOG = logging.getLogger(__name__)
 LOG_FILE = '/tmp/ontap_apis.log'
-ZAPI_DEPRECATION_MESSAGE = "With version 22.0.0 ONTAPI (ZAPI) has been deprecated. The final ONTAP version to support ZAPI is ONTAP 9.12.1.  "\
-                           "ZAPI calls in these modules will continue to work for ONTAP versions that supports ZAPI.  "\
-                           "You can update your playbook to use REST by adding use_rest: always to your playbook.  "\
-                           "More information can be found at: https://github.com/ansible-collections/netapp.ontap"
+ZAPI_DEPRECATION_MESSAGE = "With collection version 22.0.0 ONTAPI (ZAPI) has been deprecated.  "\
+                           "The 'netapp-lib' library is no longer maintained. Proceed at your own risk.  "\
+                           "To ensure continued support, please migrate to the REST API."
 
 try:
     from solidfire.factory import ElementFactory
@@ -151,7 +150,7 @@ def na_ontap_zapi_only_spec():
 
 
 def na_ontap_host_argument_spec():
-    # This is used for Zapi + REST, and REST only Modules.
+    # This is used for Zapi + REST Modules.
 
     return dict(
         hostname=dict(required=True, type='str'),
@@ -161,7 +160,25 @@ def na_ontap_host_argument_spec():
         validate_certs=dict(required=False, type='bool', default=True),
         http_port=dict(required=False, type='int'),
         ontapi=dict(required=False, type='int'),
-        use_rest=dict(required=False, type='str', default='auto'),
+        use_rest=dict(required=False, type='str', default='always'),
+        feature_flags=dict(required=False, type='dict'),
+        cert_filepath=dict(required=False, type='str'),
+        key_filepath=dict(required=False, type='str', no_log=False),
+        force_ontap_version=dict(required=False, type='str')
+    )
+
+
+def na_ontap_rest_only_spec():
+    # This is used for REST only Modules.
+
+    return dict(
+        hostname=dict(required=True, type='str'),
+        username=dict(required=False, type='str', aliases=['user']),
+        password=dict(required=False, type='str', aliases=['pass'], no_log=True),
+        https=dict(required=False, type='bool', default=False),
+        validate_certs=dict(required=False, type='bool', default=True),
+        http_port=dict(required=False, type='int'),
+        use_rest=dict(required=False, type='str', default='always'),
         feature_flags=dict(required=False, type='dict'),
         cert_filepath=dict(required=False, type='str'),
         key_filepath=dict(required=False, type='str', no_log=False),
@@ -204,7 +221,7 @@ def get_feature(module, feature_name):
         always_wrap_zapi=True,                  # for better error reporting
         flexcache_delete_return_timeout=5,      # ONTAP bug if too big?
         # for SVM, whch protocols can be allowed
-        svm_allowable_protocols_rest=['cifs', 'fcp', 'iscsi', 'nvme', 'nfs', 'ndmp'],
+        svm_allowable_protocols_rest=['cifs', 'fcp', 'iscsi', 'nvme', 'nfs', 'ndmp', 's3'],
         svm_allowable_protocols_zapi=['cifs', 'fcp', 'iscsi', 'nvme', 'nfs', 'ndmp', 'http'],
         max_files_change_threshold=1,           # percentage of increase/decrease required to trigger a modify action
         warn_or_fail_on_fabricpool_backend_change='fail',
@@ -248,22 +265,18 @@ def create_sf_connection(module, port=None, host_options=None):
 
 def set_auth_method(module, username, password, cert_filepath, key_filepath):
     error = None
-    if password is None and username is None:
-        if cert_filepath is None:
+    auth_method = None
+    # defaults to cert authentication if both basic and client certificate authentication parameters are given
+    if cert_filepath is not None:
+        auth_method = 'single_cert' if key_filepath is None else 'cert_key'
+    else:
+        if password is None and username is None:
             error = ('Error: cannot have a key file without a cert file' if key_filepath is not None
                      else 'Error: ONTAP module requires username/password or SSL certificate file(s)')
-        else:
-            auth_method = 'single_cert' if key_filepath is None else 'cert_key'
-    elif password is not None and username is not None:
-        if cert_filepath is not None or key_filepath is not None:
-            error = 'Error: cannot have both basic authentication (username/password) ' +\
-                    'and certificate authentication (cert/key files)'
-        else:
+        elif password is not None and username is not None:
             auth_method = 'basic_auth' if has_feature(module, 'classic_basic_authorization') else 'speedy_basic_auth'
-    else:
-        error = 'Error: username and password have to be provided together'
-        if cert_filepath is not None or key_filepath is not None:
-            error += ' and cannot be used with cert or key files'
+        else:
+            error = 'Error: username and password have to be provided together'
     if error:
         module.fail_json(msg=error)
     return auth_method
@@ -878,12 +891,26 @@ class OntapRestAPI(object):
 
     def post(self, api, body, params=None, headers=None, files=None):
         method = 'POST'
-        dummy, message, error = self.send_request(method, api, params, json=body, headers=headers, files=files)
+        retry = 3
+        while retry > 0:
+            dummy, message, error = self.send_request(method, api, params, json=body, headers=headers, files=files)
+            if error and isinstance(error, dict) and 'temporarily locked' in error.get('message', ''):
+                time.sleep(30)
+                retry = retry - 1
+                continue
+            break
         return message, error
 
     def patch(self, api, body, params=None, headers=None, files=None):
         method = 'PATCH'
-        dummy, message, error = self.send_request(method, api, params, json=body, headers=headers, files=files)
+        retry = 3
+        while retry > 0:
+            dummy, message, error = self.send_request(method, api, params, json=body, headers=headers, files=files)
+            if error and isinstance(error, dict) and 'temporarily locked' in error.get('message', ''):
+                time.sleep(30)
+                retry = retry - 1
+                continue
+            break
         return message, error
 
     def delete(self, api, body=None, params=None, headers=None):
@@ -972,6 +999,8 @@ class OntapRestAPI(object):
             if error and 'are available in precluster.' in error.get('message', ''):
                 # in precluster mode, version is not available :(
                 status_code, message, error = self.get_node_version_using_rest()
+            if error and 'User is not authorized.' in error.get('message', ''):
+                self.module.fail_json('User is not authorized.')
         except AttributeError:
             pass
         self.set_version(message)
@@ -1018,8 +1047,11 @@ class OntapRestAPI(object):
         if self.use_rest == 'never':
             # force ZAPI if requested
             return False, None
-        # don't send a new request if we already know the version
-        status_code = self.get_ontap_version_using_rest() if self.get_ontap_version() == (-1, -1, -1) else 200
+        # Check if ONTAP version is already known
+        if self.ontap_version['valid']:
+            status_code = 200
+        else:
+            status_code = self.get_ontap_version_using_rest()
         if self.use_rest == "always" and partially_supported_rest_properties:
             # If a variable is on a list we need to move it to a dict for this check to work correctly.
             temp_parameters = parameters.copy()
