@@ -243,7 +243,7 @@ ALL_SUBSETS = ['application/applications',
                'cluster',
                'cluster/chassis',
                'cluster/counter/tables',
-               'cluster/fireware/history',
+               'cluster/firmware/history',
                'cluster/jobs',
                'cluster/licensing/capacity-pools',
                'cluster/licensing/license-managers',
