@@ -1,4 +1,4 @@
-# (c) 2018-2022, NetApp, Inc
+# (c) 2018-2025, NetApp, Inc
 # GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
 
 ''' unit tests ONTAP Ansible module: na_ontap_software_update '''
@@ -10,6 +10,7 @@ import pytest
 import sys
 
 from ansible_collections.netapp.ontap.tests.unit.compat.mock import patch
+# pylint: disable=unused-import
 from ansible_collections.netapp.ontap.tests.unit.plugins.module_utils.ansible_mocks import\
     assert_warning_was_raised, expect_and_capture_ansible_exception, call_main, create_module, create_and_apply, patch_ansible, print_warnings
 from ansible_collections.netapp.ontap.tests.unit.framework.mock_rest_and_zapi_requests import\
@@ -201,8 +202,6 @@ DEFAULT_ARGS = {
 @patch('time.sleep')
 def test_ensure_apply_for_update_called(dont_sleep):
     register_responses([
-        ('ZAPI', 'vserver-get-iter', ZRR['cserver']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'cluster-image-package-local-get-iter', ZRR['no_records']),
         ('ZAPI', 'cluster-image-get-iter', ZRR['cluster_image_info']),
         ('ZAPI', 'cluster-image-package-download', ZRR['success']),
@@ -223,8 +222,6 @@ def test_ensure_apply_for_update_called(dont_sleep):
 @patch('time.sleep')
 def test_ensure_apply_for_update_called_node(dont_sleep):
     register_responses([
-        ('ZAPI', 'vserver-get-iter', ZRR['cserver']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'cluster-image-package-local-get-iter', ZRR['no_records']),
         ('ZAPI', 'cluster-image-get', ZRR['cluster_image_info']),
         ('ZAPI', 'cluster-image-package-download', ZRR['success']),
@@ -247,8 +244,6 @@ def test_ensure_apply_for_update_called_node(dont_sleep):
 def test_ensure_apply_for_update_called_idempotent(dont_sleep):
     # image already installed
     register_responses([
-        ('ZAPI', 'vserver-get-iter', ZRR['cserver']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'cluster-image-package-local-get-iter', ZRR['no_records']),
         ('ZAPI', 'cluster-image-get-iter', ZRR['cluster_image_info']),
 
@@ -263,8 +258,6 @@ def test_ensure_apply_for_update_called_idempotent(dont_sleep):
 def test_ensure_apply_for_update_called_idempotent_node(dont_sleep):
     # image already installed
     register_responses([
-        ('ZAPI', 'vserver-get-iter', ZRR['cserver']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'cluster-image-package-local-get-iter', ZRR['no_records']),
         ('ZAPI', 'cluster-image-get', ZRR['cluster_image_info']),
 
@@ -280,8 +273,6 @@ def test_ensure_apply_for_update_called_idempotent_node(dont_sleep):
 def test_ensure_apply_for_update_called_with_validation(dont_sleep):
     # for validation before update
     register_responses([
-        ('ZAPI', 'vserver-get-iter', ZRR['cserver']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'cluster-image-package-local-get-iter', ZRR['no_records']),
         ('ZAPI', 'cluster-image-get-iter', ZRR['cluster_image_info']),
         ('ZAPI', 'cluster-image-package-download', ZRR['success']),
@@ -305,8 +296,6 @@ def test_ensure_apply_for_update_called_with_validation(dont_sleep):
 def test_negative_download_error(dont_sleep):
     ''' downloading software - error while downloading the image - first request '''
     register_responses([
-        ('ZAPI', 'vserver-get-iter', ZRR['cserver']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'cluster-image-package-local-get-iter', ZRR['no_records']),
         ('ZAPI', 'cluster-image-get-iter', ZRR['cluster_image_info']),
         ('ZAPI', 'cluster-image-package-download', ZRR['error']),
@@ -323,8 +312,6 @@ def test_negative_download_error(dont_sleep):
 def test_negative_download_progress_error(dont_sleep):
     ''' downloading software - error while downloading the image - progress error '''
     register_responses([
-        ('ZAPI', 'vserver-get-iter', ZRR['cserver']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'cluster-image-package-local-get-iter', ZRR['no_records']),
         ('ZAPI', 'cluster-image-get-iter', ZRR['cluster_image_info']),
         ('ZAPI', 'cluster-image-package-download', ZRR['success']),
@@ -344,8 +331,6 @@ def test_negative_download_progress_error(dont_sleep):
 def test_negative_download_progress_error_no_status(dont_sleep):
     ''' downloading software - error while downloading the image - progress error '''
     register_responses([
-        ('ZAPI', 'vserver-get-iter', ZRR['cserver']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'cluster-image-package-local-get-iter', ZRR['no_records']),
         ('ZAPI', 'cluster-image-get-iter', ZRR['cluster_image_info']),
         ('ZAPI', 'cluster-image-package-download', ZRR['success']),
@@ -368,8 +353,6 @@ def test_negative_download_progress_error_no_status(dont_sleep):
 def test_negative_download_progress_error_fetching_status(dont_sleep):
     ''' downloading software - error while downloading the image - progress error '''
     register_responses([
-        ('ZAPI', 'vserver-get-iter', ZRR['cserver']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'cluster-image-package-local-get-iter', ZRR['no_records']),
         ('ZAPI', 'cluster-image-get-iter', ZRR['cluster_image_info']),
         ('ZAPI', 'cluster-image-package-download', ZRR['success']),
@@ -389,8 +372,6 @@ def test_negative_download_progress_error_fetching_status(dont_sleep):
 def test_negative_update_error_zapi(dont_sleep):
     ''' updating software - error while updating the image '''
     register_responses([
-        ('ZAPI', 'vserver-get-iter', ZRR['cserver']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'cluster-image-package-local-get-iter', ZRR['no_records']),
         ('ZAPI', 'cluster-image-get-iter', ZRR['cluster_image_info']),
         ('ZAPI', 'cluster-image-package-download', ZRR['success']),
@@ -413,8 +394,6 @@ def test_negative_update_error_zapi(dont_sleep):
 def test_negative_update_error(dont_sleep):
     ''' updating software - error while updating the image '''
     register_responses([
-        ('ZAPI', 'vserver-get-iter', ZRR['cserver']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'cluster-image-package-local-get-iter', ZRR['no_records']),
         ('ZAPI', 'cluster-image-get-iter', ZRR['cluster_image_info']),
         ('ZAPI', 'cluster-image-package-download', ZRR['success']),
@@ -437,8 +416,6 @@ def test_negative_update_error(dont_sleep):
 def test_negative_update_error_timeout(dont_sleep):
     ''' updating software - error while updating the image '''
     register_responses([
-        ('ZAPI', 'vserver-get-iter', ZRR['cserver']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'cluster-image-package-local-get-iter', ZRR['no_records']),
         ('ZAPI', 'cluster-image-get-iter', ZRR['cluster_image_info']),
         ('ZAPI', 'cluster-image-package-download', ZRR['success']),
@@ -468,9 +445,10 @@ def test_fail_netapp_lib_error(mock_has_netapp_lib):
 
 
 def test_fail_with_http():
-    args = dict(DEFAULT_ARGS)
-    args.pop('https')
-    assert 'Error: https parameter must be True' == call_main(my_main, args, fail=True)['msg']
+    module_args = {
+        'https': False
+    }
+    assert 'Error: https parameter must be True' == call_main(my_main, DEFAULT_ARGS, module_args, fail=True)['msg']
 
 
 def test_is_update_required():
@@ -582,13 +560,9 @@ def test_cluster_image_update_progress_get_error():
 def test_delete_package_zapi():
     # deleting a package
     register_responses([
-        ('ZAPI', 'vserver-get-iter', ZRR['cserver']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'cluster-image-package-local-get-iter', ZRR['cluster_image_package_local_info']),
         ('ZAPI', 'cluster-image-package-delete', ZRR['success']),
         # idempotency
-        ('ZAPI', 'vserver-get-iter', ZRR['cserver']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'cluster-image-package-local-get-iter', ZRR['no_records']),
     ])
     module_args = {
