@@ -9,7 +9,6 @@ __metaclass__ = type
 
 
 class ModuleDocFragment(object):
-
     # Standard Pure Storage documentation fragment
     DOCUMENTATION = r"""
 options:
@@ -31,13 +30,24 @@ options:
     description:
       - FlashBlade API token for admin privileged user.
     type: str
+  disable_warnings:
+    description:
+    - Disable insecure certificate warnings
+    type: bool
+    default: false
+    version_added: '1.18.0'
 notes:
   - This module requires the C(purity_fb) Python library
   - You must set C(PUREFB_URL) and C(PUREFB_API) environment variables
     if I(fb_url) and I(api_token) arguments are not passed to the module directly
 requirements:
-  - python >= 2.7
-  - purity_fb >= 1.9
+  - python >= 3.9
+  - py-pure-client
+  - purity_fb >= 1.12.2
   - netaddr
+  - datetime
   - pytz
+  - distro
+  - pycountry
+  - urllib3
 """
